(* $Id: godi_profile_ops.mli 1096 2012-10-15 14:55:17Z gerd $ *)

open Godi_types
open Godi_exec


val list : unit -> string list
  (* Returns the names of all locally available profiles *)

val commented_list : unit -> (string * string) list
  (* Returns the names and comments of all locally available profiles *)

val enable : string -> unit
  (* Enables this profile:
     - sets the [GODI_PROFILE] variable
     - updates [profile.conf]
     - updates the profile patches

     This function does not do anything further (like updating the available
     packages, extracting packages, building packages).
   *)

val current : unit -> Godi_profile.profile
  (* Returns the current profile *)

val update : console -> unit
  (* Updates the list of available packages for all sources of the current
     profile
   *)

val extract : ?constraints:Godi_versions.dependency list -> console -> unit
  (* Extracts the right build.tgz files for the current profile

     constraints: These are additional ad-hoc constraints which build
     instructions are actually extracted when there are several versions
   *)

val wish : console -> unit
  (* Writes the wish list so that all packages are rebuilt where the
     current profile demands a different package than is currently installed.
     
     So far, package options are no criterion for wishing. Ideally, however,
     new package options should also be an indicator for a rebuild.
   *)

val copy : string -> string -> unit
  (* [copy src dest]: Copies the profile [src] to [dest] *)

val delete : string -> unit
  (* Deletes this profile. It is not allowed to delete the current profile *)

val save_patches : console -> unit
  (* Saves the patches found in profile-patches/, so that they appear
     in profile.ini
   *)

val rget : Wtool_types.wtool_factory -> string -> string -> unit
  (* [rget w url name]: Get profile [name] from [url]. A local profile of the
     same name is only overwritten if its origin is the same [url]
   *)

val rupdate : Wtool_types.wtool_factory -> string -> unit
  (* [rupdate w name]: Get profile [name] from its origin
   *)

val rput : Wtool_types.wtool_factory -> string -> string -> unit
  (* [rput w url name]: Uploads profile [name] to [url] *)

val rlist : Wtool_types.wtool_factory -> string -> string list
  (* [rlist w url]: Returns the names of remote profiles at this url *)

val rupdate_current : console -> unit
  (* Updates the current profile (with user messages), provided there is
     an origin URL
   *)

